Welcome to the documentation of ``epspy``!
===========================================

.. toctree::
   :maxdepth: 5
   :caption: Contents:

   Basics <basics>

   Detailed explanation <detexp>

   More functions <otherfuncs>
   
   API Reference <api>
   
   FAQs <faqs>
